summaryrefslogtreecommitdiffstats
path: root/ProcessList.h
diff options
context:
space:
mode:
authorNathan Scott <nathans@redhat.com>2021-03-30 15:55:48 +1100
committerSohaib <sohaib.amhmd@gmail.com>2021-04-05 23:41:07 +0200
commit356488aa53e8c0bedeb7641685d931c8900098c5 (patch)
treec09f2df8264cc4075b72a55409ae261c021cda55 /ProcessList.h
parent421bdeec603b4fb1a4edec0e802c437fbe47fca0 (diff)
Request the realtime and monotonic clock times once per sample
Refactor the sample time code to make one call to gettimeofday (aka the realtime clock in clock_gettime, when available) and one to the monotonic clock. Stores each in more appropriately named ProcessList fields for ready access when needed. Every platform gets the opportunity to provide their own clock code, and the existing Mac OS X specific code is moved below darwin instead of in Compat. A couple of leftover time(2) calls are converted to use these ProcessList fields as well, instead of yet again sampling the system clock. Related to https://github.com/htop-dev/htop/pull/574
Diffstat (limited to 'ProcessList.h')
-rw-r--r--ProcessList.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/ProcessList.h b/ProcessList.h
index 46944dbd..7d98197d 100644
--- a/ProcessList.h
+++ b/ProcessList.h
@@ -48,8 +48,9 @@ typedef struct ProcessList_ {
Hashtable* displayTreeSet;
Hashtable* draftingTreeSet;
- struct timeval timestamp; /* time of the current sample */
- uint64_t timestampMs; /* current time in milliseconds */
+ struct timeval realtime; /* time of the current sample */
+ uint64_t realtimeMs; /* current time in milliseconds */
+ uint64_t monotonicMs; /* same, but from monotonic clock */
Panel* panel;
int following;
@@ -79,8 +80,6 @@ typedef struct ProcessList_ {
memory_t cachedSwap;
unsigned int cpuCount;
-
- time_t scanTs;
} ProcessList;
ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidMatchList, uid_t userId);

© 2014-2024 Faster IT GmbH | imprint | privacy policy